PieceShiftMethod enum
Describes how moves are made on an interactive board.
Values
- tapTwoSquares → const PieceShiftMethod
-
First tap the piece to be moved, then tap the target square.
- drag → const PieceShiftMethod
-
Drag-and-drop the piece to the target square.
- either → const PieceShiftMethod
-
Both tap and drag are enabled.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PieceShiftMethod> - A constant List of the values in this enum, in order of their declaration.