ValidMoves typedef
ValidMoves = IMap<Square, ISet<Square> >
Sets of each valid destinations for an origin square.
Implementation
typedef ValidMoves = IMap<Square, ISet<Square>>;
Sets of each valid destinations for an origin square.
typedef ValidMoves = IMap<Square, ISet<Square>>;